[![travis](https://travis-ci.org/MichaelClerx/myokit.svg?branch=master)](https://travis-ci.org/MichaelClerx/myokit)
[![appveyor](https://ci.appveyor.com/api/projects/status/u2e6bc6tklgxyyra?svg=true)](https://ci.appveyor.com/project/MichaelClerx/myokit)
[![codecov](https://codecov.io/gh/MichaelClerx/myokit/branch/master/graph/badge.svg)](https://codecov.io/gh/MichaelClerx/myokit)
[![Documentation Status](https://readthedocs.org/projects/myokit/badge/?version=latest)](https://myokit.readthedocs.io/?badge=latest)

# Myokit

Myokit is an [open-source](https://github.com/MichaelClerx/myokit/blob/master/LICENSE.txt) Python-based toolkit that facilitates modeling and simulation of cardiac cellular electrophysiology.

For details, see [myokit.org](http://myokit.org)

For the latest documentation, see [myokit.readthedocs.io](https://myokit.readthedocs.io/)

## Installation

To install Myokit, use `pip install myokit`, or follow the [guidelines on the download pages](http://myokit.org/download).

## Quick-start guide

After installation, to quickly test if Myokit works, open a command window, navigate to the myokit directory and type

    python myo run example
    
To open an IDE window, type

    python myo ide
    
To see what else the `myo` script can do, type

    python myo -h

## Adding icons etc.
If you're a Gnome or KDE user, you may wish to install a Myokit icon to your menu, add the mime-type information for Myokit `.mmt` files or add syntax highlighting for gtksourceview (Gedit). Scripts to do this are located in
    
    ./install/gnome-kde

Options for windows users are coming soon!
